@@ -247,8 +247,6 @@ extern devclass_t nvidia_devclass;
 extern struct nvidia_softc nvidia_ctl_sc;
 extern nv_state_t nvidia_ctl_state;
 
-extern const char *pNVRM_ID;
-
 #define PCIR_CAP_LIST_ID   0x00
 #define PCIR_CAP_LIST_NEXT 0x01
 #define PCIR_CAP_ID_AGP    0x02
@@ -271,15 +269,6 @@ extern const char *pNVRM_ID;
 #define PAT_WRITE_BACK          0x06
 #endif
 
-/*
- * Entries in the NVIDIA glue-layer registry are now described by the new
- * shared nv_parm_t structure; please review nvidia_os_registry.c in case
- * you need to make low-level configuration changes. The entries are also
- * mapped into the SYSCTL hierarchy and thus easily accessible.
- */
-
-extern nv_parm_t nv_parms[];
-
 /*
  * These macros extract the encoded ioctl type and number from the
  * command; we inspect the type to verify that device/control ioctls
