@@ -518,8 +518,11 @@ typedef struct
 #endif /* !defined(NV_API_CALL) */
 
 
-void*  NV_API_CALL  nv_alloc_kernel_mapping      (nv_state_t *, NvU64, NvU32, void **);
-NvS32  NV_API_CALL  nv_free_kernel_mapping       (nv_state_t *, void *, void *, BOOL);
+void*  NV_API_CALL  nv_alloc_kernel_mapping      (nv_state_t *, NvU64, NvU64, void **);
+RM_STATUS  NV_API_CALL  nv_free_kernel_mapping   (nv_state_t *, void *, void *, NvBool);
+
+void*  NV_API_CALL  nv_alloc_user_mapping        (nv_state_t *, NvU64, NvU64, NvU32, void **);
+RM_STATUS  NV_API_CALL  nv_free_user_mapping     (nv_state_t *, void *, void *);
 
 NvU64  NV_API_CALL  nv_get_kern_phys_address     (NvU64);
 NvU64  NV_API_CALL  nv_get_user_phys_address     (NvU64);
@@ -563,10 +566,6 @@ RM_STATUS  NV_API_CALL  nv_log_error             (nv_state_t *, NvU32, const cha
 #ifdef NV_USER_MAP
 #include "nv-map.h"
 #else /* NV_USER_MAP */
-#define NV_MAP_USER_SPACE(nv, file, va, sz, pr, hclient, hparent, hobject)  do { } while (0)
-#define NV_UNMAP_USER_SPACE(nv, file, hclient, hparent, hobject, va)  do { } while (0)
-#define NV_UNMAP_OBJECT_USER_SPACE(nv, file, hclient, hparent, hobject)  do { } while (0)
-#define NV_RELEASE_USERMAP_LIST(nvl,fp) do { } while (0)
 #define NV_FILE_REFERENCE(file_p) ((void *) (file_p))
 #define NV_GET_VOID_FILE_PRIVATE(vfp_p) (NV_GET_FILE_PRIVATE(((struct file * ) (vfp_p))))
 #endif /* NV_USER_MAP */
